==> haskell-servant-swagger-1.1.5-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-5HC2Tcp5vew2EOdmvXPPzK
key: servant-swagger-1.1.5-5HC2Tcp5vew2EOdmvXPPzK
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 118063ad4ec3994505bbc1578b8fa85a
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-5HC2Tcp5vew2EOdmvXPPzK
depends:
    aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1 base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-1MyCMF6pVJzKcKPOvNQmZS
    lens-4.16.1-HRralbhzfidGpPdYquz4lt
    servant-0.13.0.1-IQaOH1qUa2nAk7dOG59jNe
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-1C8IJ42cOMt7dlWlqLwudN text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    hspec-2.5.1-4mko5AGcS2MGo1mWvISV5N
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1=35b49024653eeb9b79eed81b6925c2b9
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             insert-ordered-containers-0.2.1.0-1MyCMF6pVJzKcKPOvNQmZS=ea9b10293e927fcd48b18fef6175d84a
             lens-4.16.1-HRralbhzfidGpPdYquz4lt=cbd87dfbf6626189c53622aec5e019f0
             servant-0.13.0.1-IQaOH1qUa2nAk7dOG59jNe=badacb15830e33f1bae4a9912d30b7c3
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             swagger2-2.2.2-1C8IJ42cOMt7dlWlqLwudN=1e33a752b78f7724dbee28e8f895d3d7
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             hspec-2.5.1-4mko5AGcS2MGo1mWvISV5N=8170d3624398d81e3cc95fc8edd4d1ca
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.5-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.5
id: servant-swagger-1.1.5-IVdSygNWihP7iY7VPMRQnB
key: servant-swagger-1.1.5-IVdSygNWihP7iY7VPMRQnB
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger™ is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 88c41ca14fcbb50b7605d1d0e9a1e919
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Test Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-swagger-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-swagger-1.1.5
hs-libraries: HSservant-swagger-1.1.5-IVdSygNWihP7iY7VPMRQnB
depends:
    aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf base-4.11.1.0
    bytestring-0.10.8.2 http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    insert-ordered-containers-0.2.1.0-DoeuHtOgqwJIpaECcBxOzk
    lens-4.16.1-GNKndZKWoaUJOTzESUqMhb
    servant-0.13.0.1-AN05jt3MFKGIVgEBkqy1xK
    singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C
    swagger2-2.2.2-B0JhnEK2LTtIFiTsv5pSUf text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    hspec-2.5.2-6XADR8aaO0y5tg1Lna4bZU
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
abi-depends: aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             insert-ordered-containers-0.2.1.0-DoeuHtOgqwJIpaECcBxOzk=4e2c02e40bda9d77ea0e98115208a584
             lens-4.16.1-GNKndZKWoaUJOTzESUqMhb=3e8d4b6a5f0712b892b001fd54399166
             servant-0.13.0.1-AN05jt3MFKGIVgEBkqy1xK=6efa036d189f8337c529097c574e222c
             singleton-bool-0.1.4-8EznQE6dMi2H7lit14Cx2C=224d0377dd86bfef9c4c84d4841ba81f
             swagger2-2.2.2-B0JhnEK2LTtIFiTsv5pSUf=62e16e5c2f0b4d58117a4ac4fb5f29c1
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             hspec-2.5.2-6XADR8aaO0y5tg1Lna4bZU=31f2da17a75490a92092c0cedf462d80
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
